#Plot scalar quantities
import numpy as np
import matplotlib.pyplot as plt
import matplotlib.ticker as ticker
from matplotlib.ticker import NullFormatter
import matplotlib.gridspec as gridspec
import matplotlib

#units
uc = 2.99792458*10**(10)
uG = 6.67428*10**(-8)
uMs = 1.9884*10**(33)
utime = uG*uMs/uc**3*1000
ulenght = (uG*uMs/uc**2)/100000
urho = (uc**6)/(uG**3*uMs**2)
normalnuc = 2.705*10**(14)

#plot settings
params = {
#    'figure.figsize'    : [9, 4],
    'text.usetex'       : True,
    'xtick.major.size'  : 10,
    'xtick.minor.size'  : 5,
    'ytick.major.size'  : 10,
    'ytick.minor.size'  : 5,
}
matplotlib.rcParams.update(params) 
TickLabelSize=18
TickMajorLength=15
LabelSize=20

#plotting grid
plt.figure(0)
gs = gridspec.GridSpec(2, 1, hspace=0.05)
ax1 = plt.subplot(gs[0])
ax2 = plt.subplot(gs[1])

#read in data
data_alp=[]
data_rho=[]
data_alp.append(np.loadtxt("./../data/Cow-dx04/alp.minimum.asc"))
data_rho.append(np.loadtxt("./../data/Cow-dx04/rho.maximum.asc"))

#plot data
lw=1.8
ax1.plot(utime*data_alp[0][:,1],data_alp[0][:,2],c="blue", linewidth=lw,label=r"$\rm Cowling:\, dx=0.4$")
ax2.plot(utime*data_rho[0][:,1],urho/normalnuc*data_rho[0][:,2],c="blue", linewidth=lw)

#remove the labels from top figure
ax1.xaxis.set_major_formatter(ticker.NullFormatter())

#set labels
ax1.set_ylabel(r"$\rm \alpha_{min}$",size=LabelSize)
ax2.set_ylabel(r"$\rm \rho_{max}/\!\rho_{0}$",size=LabelSize)
ax2.set_xlabel(r"$\rm t \, [ms]$",size=LabelSize)

#show legend
ax1.legend(shadow=False, frameon=False,ncol=1, fontsize=11,loc='lower right')
#ax2.legend(shadow=False, frameon=False,ncol=1, fontsize=11,loc='upper right')

#save figure
saveFig="./alp-rho-t.jpg"
plt.savefig(saveFig, dpi=400,bbox_inches="tight",pad_inches=0.05,format="jpg")
#saveFig="./pics/alp-rho-M132-v8.pdf"
#plt.savefig(saveFig,bbox_inches="tight",pad_inches=0.05,format="pdf")
plt.show()

